@@ -28,30 +28,16 @@
  */
 
 #include "MSPUBSVGGenerator.h"
-#include "libmspub.h"
 #include <locale.h>
 #include <sstream>
 #include <string>
 
 static std::string doubleToString(const double value)
 {
-  std::ostringstream tempStream;
-  tempStream << value;
-#ifndef __ANDROID__
-  std::string decimalPoint(localeconv()->decimal_point);
-#else
-  std::string decimalPoint(".");
-#endif
-  if ((decimalPoint.size() == 0) || (decimalPoint == "."))
-    return tempStream.str();
-  std::string stringValue(tempStream.str());
-  if (!stringValue.empty())
-  {
-    std::string::size_type pos;
-    while ((pos = stringValue.find(decimalPoint)) != std::string::npos)
-      stringValue.replace(pos,decimalPoint.size(),".");
-  }
-  return stringValue;
+  WPXProperty *prop = WPXPropertyFactory::newDoubleProp(value);
+  std::string retVal = prop->getStr().cstr();
+  delete prop;
+  return retVal;
 }
 
 static unsigned stringToColour(const ::WPXString &s)
@@ -546,9 +532,10 @@ void libmspub::MSPUBSVGGenerator::writeStyle(bool /* isClosed */)
 {
   m_outputSink << "style=\"";
 
+  double width = 1.0 / 72.0;
   if (m_style["svg:stroke-width"])
   {
-    double width = m_style["svg:stroke-width"]->getDouble();
+    width = m_style["svg:stroke-width"]->getDouble();
     if (width == 0.0 && m_style["draw:stroke"] && m_style["draw:stroke"]->getStr() != "none")
       width = 0.2 / 72.0; // reasonable hairline
     m_outputSink << "stroke-width: " << doubleToString(72*width) << "; ";
@@ -562,29 +549,39 @@ void libmspub::MSPUBSVGGenerator::writeStyle(bool /* isClosed */)
   }
 
   if (m_style["draw:stroke"] && m_style["draw:stroke"]->getStr() == "solid")
-    m_outputSink << "stroke-dasharray:  solid; ";
-  else if (m_style["draw:stroke"] && m_style["draw:stroke"]->getStr() == "dash")
+    m_outputSink << "stroke-dasharray:  none; ";
+  if (m_style["draw:stroke"] && m_style["draw:stroke"]->getStr() == "dash")
   {
-    int dots1 = m_style["draw:dots1"]->getInt();
-    int dots2 = m_style["draw:dots2"]->getInt();
-    double dots1len = m_style["draw:dots1-length"]->getDouble();
-    double dots2len = m_style["draw:dots2-length"]->getDouble();
-    double gap = m_style["draw:distance"]->getDouble();
+    int dots1 = 0;
+    if (m_style["draw:dots1"])
+      dots1 = m_style["draw:dots1"]->getInt();
+    int dots2 = 0;
+    if (m_style["draw:dots2"])
+      dots2 = m_style["draw:dots2"]->getInt();
+    double dots1len = width * 72.0;
+    double dots2len = width * 72.0;
+    double gap = width * 72.0;
+    if (m_style["draw:dots1-length"])
+      dots1len = m_style["draw:dots1-length"]->getDouble() * 72.0;
+    if (m_style["draw:dots2-length"])
+      dots2len = m_style["draw:dots2-length"]->getDouble() * 72.0;
+    if (m_style["draw:distance"])
+      gap = m_style["draw:distance"]->getDouble() * 72.0;
     m_outputSink << "stroke-dasharray: ";
     for (int i = 0; i < dots1; i++)
     {
       if (i)
         m_outputSink << ", ";
-      m_outputSink << (int)dots1len;
+      m_outputSink << dots1len;
       m_outputSink << ", ";
-      m_outputSink << (int)gap;
+      m_outputSink << gap;
     }
     for (int j = 0; j < dots2; j++)
     {
       m_outputSink << ", ";
-      m_outputSink << (int)dots2len;
+      m_outputSink << dots2len;
       m_outputSink << ", ";
-      m_outputSink << (int)gap;
+      m_outputSink << gap;
     }
     m_outputSink << "; ";
   }
